[Scummvm-cvs-logs] CVS: scummvm/saga game.cpp,1.37,1.38 saga.h,1.54,1.55

Eugene Sandulenko sev at users.sourceforge.net
Sat Dec 25 02:33:01 CET 2004


Update of /cvsroot/scummvm/scummvm/saga
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv18794

Modified Files:
	game.cpp saga.h 
Log Message:
There appeared to be different DOS CD version. Also fixed DOS demo detection


Index: saga.h
===================================================================
RCS file: /cvsroot/scummvm/scummvm/saga/saga.h,v
retrieving revision 1.54
retrieving revision 1.55
diff -u -d -r1.54 -r1.55
--- saga.h	24 Dec 2004 20:44:39 -0000	1.54
+++ saga.h	25 Dec 2004 10:32:05 -0000	1.55
@@ -123,7 +123,7 @@
 	GID_ITE_MAC_G,  // TODO
 
 	// Wyrmkeep
-	//GID_ITE_CD,    // data for Win rerelease is same as in old DOS
+	GID_ITE_CD,       // data for Win rerelease is same as in old DOS
 	GID_ITE_MACCD,
 	GID_ITE_LINCD,
 	GID_ITE_WINDEMO1, // older Wyrmkeep windows demo





More information about the Scummvm-git-logs mailing list
Index: game.cpp
===================================================================
RCS file: /cvsroot/scummvm/scummvm/saga/game.cpp,v
retrieving revision 1.37
retrieving revision 1.38
diff -u -d -r1.37 -r1.38
--- game.cpp	24 Dec 2004 13:01:47 -0000	1.37
+++ game.cpp	25 Dec 2004 10:32:05 -0000	1.38
@@ -207,13 +207,19 @@
 	{ GID_ITE_DISK_G,   "c46e4392fcd2e89bc91e5567db33b62d", "voices.rsc" },
 
 	{ GID_ITE_CD_G,     "8f4315a9bb10ec839253108a032c8b54", "ite.rsc" },
-	{ GID_ITE_CD_G,     "a891405405edefc69c9d6c420c868b84", "scripts.rsc" },
+	{ GID_ITE_CD_G,     "50a0d2d7003c926a3832d503c8534e90", "scripts.rsc" },
 	{ GID_ITE_CD_G,     "e2ccb61c325d6d1ead3be0e731fe29fe", "sounds.rsc" },
 	{ GID_ITE_CD_G,     "41bb6b95d792dde5196bdb78740895a6", "voices.rsc" },
 
+	{ GID_ITE_CD,       "8f4315a9bb10ec839253108a032c8b54", "ite.rsc" },
+	{ GID_ITE_CD,       "a891405405edefc69c9d6c420c868b84", "scripts.rsc" },
+	{ GID_ITE_CD,       "e2ccb61c325d6d1ead3be0e731fe29fe", "sounds.rsc" },
+	{ GID_ITE_CD,       "41bb6b95d792dde5196bdb78740895a6", "voices.rsc" },
+
 	{ GID_ITE_DEMO_G,   "986c79c4d2939dbe555576529fd37932", "ite.rsc" },
 	{ GID_ITE_DEMO_G,   "d5697dd3240a3ceaddaa986c47e1a2d7", "scripts.rsc" },
 	{ GID_ITE_DEMO_G,   "c58e67c506af4ffa03fd0aac2079deb0", "voices.rsc" },
+	{ GID_ITE_DEMO_G,   "0b9a70eb4e120b6f00579b46c8cae29e", "ite.dmo" },
 
 	{ GID_ITE_MACCD,    "4f7fa11c5175980ed593392838523060", "ite.rsc" },
 	{ GID_ITE_MACCD,    "adf1f46c1d0589083996a7060c798ad0", "scripts.rsc" },
@@ -411,11 +417,29 @@
 		0
 	},
 
 	// Inherit the earth - CD version
 	{
 		"ite",
 		GType_ITE,
 		GID_ITE_CD_G,
+		"Inherit the Earth (DOS CD Version)",
+		320, 200,
+		137,
+		ITE_DEFAULT_SCENE,
+		&ITE_Resources,
+		ARRAYSIZE(ITECD_GameFiles),
+		ITECD_GameFiles,
+		ARRAYSIZE(ITECD_GameFonts),
+		ITECD_GameFonts,
+		&ITECD_GameSound,
+		0
+	},
+
+	// Inherit the earth - CD version
+	{
+		"ite",
+		GType_ITE,
+		GID_ITE_CD,
 		"Inherit the Earth (DOS/Win32 CD Version)",
 		320, 200,
 		137,
@@ -606,7 +630,7 @@
 			tstr = file->displayName();
 			tstr.toLowercase();
 
-			if (filesList[tstr] == true) {
+			if (filesList.contains(tstr)) {
 				if (md5_file(file->path().c_str(), md5sum, NULL, FILE_MD5_BYTES)) {
 					for (int j = 0; j < 16; j++) {
 						sprintf(md5str + j*2, "%02x", (int)md5sum[j]);
@@ -411,11 +417,29 @@
 	},
 
-	// Inherit the earth - CD version
+	// Inherit the earth - DOS CD version
 	{
 		"ite",
